{% if social_networks %}
  {% for social_network in social_networks %}
    <li>
      <a href="{{ social_network.get_link }}" title="{{ social_network.get_name }}" target="_blank" rel="nofollow"><i class="fa fa-{{ social_network.get_icon }}"></i></a>
    </li>
  {% endfor %}
{% endif %}
